Authors
=======

- James Collins <collijk@uw.edu>
- Joe Wagner <joewag@uw.edu>
- Bill Britt <bbritt@uw.edu>
- Rajan Mudambi <rmudambi@uw.edu>
- Mike Richards <miker985@uw.edu>
- Emily Linebarger <elineb@uw.edu>

Current Maintainers
-------------------

- James Collins <collijk@uw.edu>
